@@ -29,50 +29,50 @@ class CommitizenEmojiCz(BaseCommitizen):
                 "message": "Select the type of change you are committing",
                 "choices": [
                     {
-                        "value": "fix 🐛",
-                        "name": "fix 🐛: A bug fix. Correlates with PATCH in SemVer",
+                        "value": "🐛 fix",
+                        "name": "🐛 fix: A bug fix",
                     },
                     {
-                        "value": "feat 🧮",
-                        "name": "feat 🧮: A new feature. Correlates with MINOR in SemVer",
+                        "value": "🎉 feat",
+                        "name": "🎉 feat: A new feature",
                     },
-                    {"value": "docs 🗒️", "name": "docs 🗒️: Documentation only changes"},
+                    {"value": "🗒️ docs", "name": "🗒️ docs: Documentation only changes"},
                     {
-                        "value": "style 😎",
+                        "value": "😎 style",
                         "name": (
-                            "style 😎: Changes that do not affect the "
+                            "😎 style: Changes that do not affect the "
                             "meaning of the code (white-space, formatting,"
                             " missing semi-colons, etc)"
                         ),
                     },
                     {
-                        "value": "refactor 🛠️",
+                        "value": "🛠️ refactor",
                         "name": (
-                            "refactor 🛠️: A code change that neither fixes "
+                            "🛠️ refactor: A code change that neither fixes "
                             "a bug nor adds a feature"
                         ),
                     },
                     {
-                        "value": "perf 🚀",
-                        "name": "perf 🚀: A code change that improves performance",
+                        "value": "🚀 perf",
+                        "name": "🚀 perf: A code change that improves performance",
                     },
                     {
-                        "value": "test 🧪",
+                        "value": "🧪 test",
                         "name": (
-                            "test 🧪: Adding missing or correcting " "existing tests"
+                            "🧪 test: Adding missing or correcting " "existing tests"
                         ),
                     },
                     {
-                        "value": "build 🏗️",
+                        "value": "🏗️ build",
                         "name": (
-                            "build 🏗️: Changes that affect the build system or "
+                            "🏗️ build: Changes that affect the build system or "
                             "external dependencies (example scopes: pip, docker, npm)"
                         ),
                     },
                     {
-                        "value": "ci 🛸",
+                        "value": "🛸 ci",
                         "name": (
-                            "ci 🛸: Changes to our CI configuration files and "
+                            "🛸 ci: Changes to our CI configuration files and "
                             "scripts (example scopes: GitLabCI)"
                         ),
                     },
@@ -96,6 +96,18 @@ class CommitizenEmojiCz(BaseCommitizen):
                     "Imperative, lower case and no final dot:\n"
                 ),
             },
+            {
+                "type": "input",
+                "name": "time",
+                "message": "Time spent (i.e. 3h 15m) (optional):\n",
+                "filter": lambda x: "⏰ " + x.strip() if x else "",
+            },
+            {
+                "type": "input",
+                "name": "tasks",
+                "message": "Tasks ID(s) separated by spaces (optional):\n",
+                "filter": lambda x: x.strip() if x else "",
+            },
             {
                 "type": "confirm",
                 "message": "Is this a BREAKING CHANGE? Correlates with MAJOR in SemVer",
@@ -111,14 +123,6 @@ class CommitizenEmojiCz(BaseCommitizen):
                 ),
                 "filter": multiple_line_breaker,
             },
-            {
-                "type": "input",
-                "name": "footer",
-                "message": (
-                    "Footer. Information about Breaking Changes and "
-                    "reference issues that this commit closes:\n"
-                ),
-            },
         ]
         return questions
 
@@ -127,8 +131,10 @@ class CommitizenEmojiCz(BaseCommitizen):
         scope = answers["scope"]
         subject = answers["subject"]
         body = answers["body"]
-        footer = answers["footer"]
         is_breaking_change = answers["is_breaking_change"]
+        time = answers["time"]
+        tasks = answers["tasks"]
+        extra = ''
 
         if scope:
             scope = f"({scope})"
@@ -136,10 +142,14 @@ class CommitizenEmojiCz(BaseCommitizen):
             body = f"BREAKING CHANGE 🚨: {body}"
         if body:
             body = f"\n\n{body}"
-        if footer:
-            footer = f"\n\n{footer}"
 
-        message = f"{prefix}{scope}: {subject}{body}{footer}"
+        if time:
+            extra += time
+        if tasks:
+            extra += 'Tasks: ' + \
+                ' '.join([f'#{task_id}' for task_id in tasks.split()])
+
+        message = f"{prefix}{scope}: {extra}{subject}{body}"
 
         return message
 
